@@ -1,9 +1,8 @@
+from typing import Mapping as _abc_Mapping
+
 from ._typed import Typed
 
 
-from collections.abc import Sequence as _abc_Sequence
-
-
 # Integer
 class Integer(Typed):
     expected_type = int
@@ -19,6 +18,16 @@ class String(Typed):
     expected_type = str
 
 
-# Sequence
-class Sequence(Typed):
-    expected_type = _abc_Sequence
+# List
+class List(Typed):
+    expected_type = list
+
+
+# Mapping
+class Mapping(Typed):
+    expected_type = _abc_Mapping
+
+
+# Tuple
+class Tuple(Typed):
+    expected_type = tuple
